@@ -117,15 +117,15 @@ class SlickLogRemoteLogger:
   __BUFER_SIZE = 16384
   __CHAR_ENCODING = 'utf8'
 
-  def __init__(self, conn_builder, spawn_new_threads=False, deamon_thread=False):
+  def __init__(self, conn_builder, spawn_new_threads=False, daemon_thread=False):
     self.shutdown_now = False
     self.conn_builder = conn_builder
     self.log_queue = new_queue(SlickLogRemoteLogger.__MAX_QUEUE_SIZE)
-    self.spawn_new_threads = spawn_new_threads and deamon_thread
+    self.spawn_new_threads = spawn_new_threads and daemon_thread
     self.data_pushed = 0
     thread = Thread(target=SlickLogRemoteLogger._get_and_push_messages, args=(self,))
     thread.setName(SlickLogRemoteLogger.__REMOTE_LOGGER_SPAWNER_THREAD_NAME)
-    thread.setDaemon(deamon_thread)
+    thread.setDaemon(daemon_thread)
     thread.start()
     self.spawning_thread = thread
 
